@@ -6,6 +6,7 @@ import colorama
 from ts_cli.commands.config_cmd import add_config_parser
 from ts_cli.commands.init_cmd import add_init_parser
 from ts_cli.commands.publish_cmd import add_publish_parser
+from ts_cli.commands.unpublish_cmd import add_unpublish_parser
 from ts_cli.util.version import check_update_required
 
 version = metadata.version("tetrascience-cli")
@@ -24,6 +25,7 @@ def main():
 
     add_init_parser(subparsers)
     add_publish_parser(subparsers)
+    add_unpublish_parser(subparsers)
     add_config_parser(subparsers)
 
     args = parser.parse_args()
